# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: controlplane/v1/control_plane.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'controlplane/v1/control_plane.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.v1 import types_pb2 as common_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#controlplane/v1/control_plane.proto\x12\x1dservicebridge.controlplane.v1\x1a\x15\x63ommon/v1/types.proto\"\x9f\x04\n\x10ReconcileRequest\x12\x39\n\x08identity\x18\x01 \x01(\x0b\x32\'.servicebridge.common.v1.WorkerIdentity\x12?\n\tfunctions\x18\x02 \x03(\x0b\x32,.servicebridge.common.v1.FunctionDeclaration\x12J\n\x0f\x63onsumer_groups\x18\x03 \x03(\x0b\x32\x31.servicebridge.common.v1.ConsumerGroupDeclaration\x12\x42\n\x0bhttp_routes\x18\x04 \x03(\x0b\x32-.servicebridge.common.v1.HttpRouteDeclaration\x12?\n\tworkflows\x18\x05 \x03(\x0b\x32,.servicebridge.common.v1.WorkflowDeclaration\x12\x35\n\x04jobs\x18\x06 \x03(\x0b\x32\'.servicebridge.common.v1.JobDeclaration\x12\x39\n\x07metrics\x18\x07 \x01(\x0b\x32(.servicebridge.common.v1.ResourceMetrics\x12>\n\x0etransport_mode\x18\x08 \x01(\x0e\x32&.servicebridge.common.v1.TransportMode\x12\x0c\n\x04zone\x18\t \x01(\t\"B\n\x11ReconcileResponse\x12\x14\n\x0clease_ttl_ms\x18\x01 \x01(\x03\x12\x17\n\x0fserver_revision\x18\x02 \x01(\x03\"\x84\x01\n\x17IssueCertificateRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x13\n\x0binstance_id\x18\x02 \x01(\t\x12\x0f\n\x07\x63sr_pem\x18\x03 \x01(\t\x12\x19\n\x11\x61\x64vertise_address\x18\x04 \x01(\t\x12\x12\n\nextra_sans\x18\x05 \x03(\t\"P\n\x18IssueCertificateResponse\x12\x10\n\x08\x63\x65rt_pem\x18\x01 \x01(\t\x12\x0e\n\x06\x63\x61_pem\x18\x02 \x01(\t\x12\x12\n\nexpires_at\x18\x03 \x01(\x03\"\xbf\x01\n\x0ePublishRequest\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12K\n\x07headers\x18\x03 \x03(\x0b\x32:.servicebridge.controlplane.v1.PublishRequest.HeadersEntry\x12\x10\n\x08trace_id\x18\x04 \x01(\t\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"%\n\x0fPublishResponse\x12\x12\n\nmessage_id\x18\x01 \x01(\t\"\\\n\x12RunWorkflowRequest\x12\x15\n\rworkflow_name\x18\x01 \x01(\t\x12\r\n\x05input\x18\x02 \x01(\x0c\x12\x0e\n\x06run_id\x18\x03 \x01(\t\x12\x10\n\x08trace_id\x18\x04 \x01(\t\"%\n\x13RunWorkflowResponse\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"7\n\x15\x43\x61ncelWorkflowRequest\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"+\n\x16\x43\x61ncelWorkflowResponse\x12\x11\n\tcancelled\x18\x01 \x01(\x08\"\x81\x01\n\x10ProxyCallRequest\x12\x15\n\rfunction_name\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x10\n\x08trace_id\x18\x03 \x01(\t\x12\x0f\n\x07span_id\x18\x04 \x01(\t\x12\x0e\n\x06run_id\x18\x05 \x01(\t\x12\x12\n\ntimeout_ms\x18\x06 \x01(\x05\"C\n\x11ProxyCallResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06output\x18\x02 \x01(\x0c\x12\r\n\x05\x65rror\x18\x03 \x01(\t2\xd3\x05\n\x0c\x43ontrolPlane\x12n\n\tReconcile\x12/.servicebridge.controlplane.v1.ReconcileRequest\x1a\x30.servicebridge.controlplane.v1.ReconcileResponse\x12\x83\x01\n\x10IssueCertificate\x12\x36.servicebridge.controlplane.v1.IssueCertificateRequest\x1a\x37.servicebridge.controlplane.v1.IssueCertificateResponse\x12h\n\x07Publish\x12-.servicebridge.controlplane.v1.PublishRequest\x1a..servicebridge.controlplane.v1.PublishResponse\x12t\n\x0bRunWorkflow\x12\x31.servicebridge.controlplane.v1.RunWorkflowRequest\x1a\x32.servicebridge.controlplane.v1.RunWorkflowResponse\x12}\n\x0e\x43\x61ncelWorkflow\x12\x34.servicebridge.controlplane.v1.CancelWorkflowRequest\x1a\x35.servicebridge.controlplane.v1.CancelWorkflowResponse\x12n\n\tProxyCall\x12/.servicebridge.controlplane.v1.ProxyCallRequest\x1a\x30.servicebridge.controlplane.v1.ProxyCallResponseBOZMgithub.com/servicebridge/server-go/internal/pb/controlplane/v1;controlplanev1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'controlplane.v1.control_plane_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZMgithub.com/servicebridge/server-go/internal/pb/controlplane/v1;controlplanev1'
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_RECONCILEREQUEST']._serialized_start=94
  _globals['_RECONCILEREQUEST']._serialized_end=637
  _globals['_RECONCILERESPONSE']._serialized_start=639
  _globals['_RECONCILERESPONSE']._serialized_end=705
  _globals['_ISSUECERTIFICATEREQUEST']._serialized_start=708
  _globals['_ISSUECERTIFICATEREQUEST']._serialized_end=840
  _globals['_ISSUECERTIFICATERESPONSE']._serialized_start=842
  _globals['_ISSUECERTIFICATERESPONSE']._serialized_end=922
  _globals['_PUBLISHREQUEST']._serialized_start=925
  _globals['_PUBLISHREQUEST']._serialized_end=1116
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._serialized_start=1070
  _globals['_PUBLISHREQUEST_HEADERSENTRY']._serialized_end=1116
  _globals['_PUBLISHRESPONSE']._serialized_start=1118
  _globals['_PUBLISHRESPONSE']._serialized_end=1155
  _globals['_RUNWORKFLOWREQUEST']._serialized_start=1157
  _globals['_RUNWORKFLOWREQUEST']._serialized_end=1249
  _globals['_RUNWORKFLOWRESPONSE']._serialized_start=1251
  _globals['_RUNWORKFLOWRESPONSE']._serialized_end=1288
  _globals['_CANCELWORKFLOWREQUEST']._serialized_start=1290
  _globals['_CANCELWORKFLOWREQUEST']._serialized_end=1345
  _globals['_CANCELWORKFLOWRESPONSE']._serialized_start=1347
  _globals['_CANCELWORKFLOWRESPONSE']._serialized_end=1390
  _globals['_PROXYCALLREQUEST']._serialized_start=1393
  _globals['_PROXYCALLREQUEST']._serialized_end=1522
  _globals['_PROXYCALLRESPONSE']._serialized_start=1524
  _globals['_PROXYCALLRESPONSE']._serialized_end=1591
  _globals['_CONTROLPLANE']._serialized_start=1594
  _globals['_CONTROLPLANE']._serialized_end=2317
# @@protoc_insertion_point(module_scope)
