# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: common/v1/types.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'common/v1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x63ommon/v1/types.proto\x12\x17servicebridge.common.v1\"`\n\x0eWorkerIdentity\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x13\n\x0binstance_id\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x03 \x01(\t\x12\x11\n\ttransport\x18\x04 \x01(\t\"[\n\x0fResourceMetrics\x12\x18\n\x0b\x63pu_percent\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x13\n\x06ram_mb\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0e\n\x0c_cpu_percentB\t\n\x07_ram_mb\"\x86\x01\n\x13\x46unctionDeclaration\x12\x0f\n\x07\x66n_name\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x05\x12\x19\n\x11input_schema_json\x18\x03 \x01(\t\x12\x1a\n\x12output_schema_json\x18\x04 \x01(\t\x12\x17\n\x0f\x61llowed_callers\x18\x05 \x03(\t\"\x97\x01\n\x18\x43onsumerGroupDeclaration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07pattern\x18\x02 \x01(\t\x12\x0c\n\x04mode\x18\x03 \x01(\t\x12\x19\n\x11retry_policy_json\x18\x04 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x05 \x01(\x08\x12\x13\n\x0b\x66ilter_expr\x18\x06 \x01(\t\x12\x0e\n\x06weight\x18\x07 \x01(\x05\"\x91\x01\n\x14HttpRouteDeclaration\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x15\n\rroute_pattern\x18\x02 \x01(\t\x12\x1b\n\x13request_schema_json\x18\x03 \x01(\t\x12\x1c\n\x14response_schema_json\x18\x04 \x01(\t\x12\x17\n\x0f\x61llowed_callers\x18\x05 \x03(\t\"E\n\x13WorkflowDeclaration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ndefinition\x18\x02 \x01(\t\x12\x0c\n\x04opts\x18\x03 \x01(\t\"\xa3\x01\n\x0eJobDeclaration\x12\x11\n\tcron_expr\x18\x01 \x01(\t\x12\x10\n\x08timezone\x18\x02 \x01(\t\x12\x16\n\x0emisfire_policy\x18\x03 \x01(\t\x12\x13\n\x0btarget_type\x18\x04 \x01(\t\x12\x12\n\ntarget_ref\x18\x05 \x01(\t\x12\x10\n\x08\x64\x65lay_ms\x18\x06 \x01(\x05\x12\x19\n\x11retry_policy_json\x18\x07 \x01(\t*d\n\rTransportMode\x12\x1e\n\x1aTRANSPORT_MODE_UNSPECIFIED\x10\x00\x12\x19\n\x15TRANSPORT_MODE_DIRECT\x10\x01\x12\x18\n\x14TRANSPORT_MODE_PROXY\x10\x02*g\n\x13LoadBalancingPolicy\x12\x12\n\x0eLB_ROUND_ROBIN\x10\x00\x12\x0f\n\x0bLB_WEIGHTED\x10\x01\x12\x18\n\x14LB_LEAST_CONNECTIONS\x10\x02\x12\x11\n\rLB_ZONE_AWARE\x10\x03*C\n\x13\x43ircuitBreakerState\x12\r\n\tCB_CLOSED\x10\x00\x12\x0b\n\x07\x43\x42_OPEN\x10\x01\x12\x10\n\x0c\x43\x42_HALF_OPEN\x10\x02\x42\x43ZAgithub.com/servicebridge/server-go/internal/pb/common/v1;commonv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/servicebridge/server-go/internal/pb/common/v1;commonv1'
  _globals['_TRANSPORTMODE']._serialized_start=917
  _globals['_TRANSPORTMODE']._serialized_end=1017
  _globals['_LOADBALANCINGPOLICY']._serialized_start=1019
  _globals['_LOADBALANCINGPOLICY']._serialized_end=1122
  _globals['_CIRCUITBREAKERSTATE']._serialized_start=1124
  _globals['_CIRCUITBREAKERSTATE']._serialized_end=1191
  _globals['_WORKERIDENTITY']._serialized_start=50
  _globals['_WORKERIDENTITY']._serialized_end=146
  _globals['_RESOURCEMETRICS']._serialized_start=148
  _globals['_RESOURCEMETRICS']._serialized_end=239
  _globals['_FUNCTIONDECLARATION']._serialized_start=242
  _globals['_FUNCTIONDECLARATION']._serialized_end=376
  _globals['_CONSUMERGROUPDECLARATION']._serialized_start=379
  _globals['_CONSUMERGROUPDECLARATION']._serialized_end=530
  _globals['_HTTPROUTEDECLARATION']._serialized_start=533
  _globals['_HTTPROUTEDECLARATION']._serialized_end=678
  _globals['_WORKFLOWDECLARATION']._serialized_start=680
  _globals['_WORKFLOWDECLARATION']._serialized_end=749
  _globals['_JOBDECLARATION']._serialized_start=752
  _globals['_JOBDECLARATION']._serialized_end=915
# @@protoc_insertion_point(module_scope)
